@@ -14,7 +14,7 @@ from pathlib import Path
 from subprocess import CalledProcessError
 from tempfile import TemporaryDirectory
 from typing import Any, BinaryIO, Iterator, List, Mapping, Optional, Set, Union, cast
-from urllib.parse import urlparse
+from urllib.parse import urljoin, urlparse
 from zipfile import ZipFile
 
 import html5lib
@@ -217,8 +217,12 @@ def get_project_from_index(
     state: AuditState,
 ) -> Iterator[Candidate]:
     """Return candidates from an index created from the project name and extras."""
-    url = index_url + "/" + project
-    response: requests.Response = session.get(url, timeout=timeout)
+
+    # NOTE: The trailing slash is important here: without it, the `urljoin`
+    # below will treat the final component as a file and strip during the join.
+    # It's also strictly more correct, per PEP 503.
+    project_url = urljoin(index_url, f"{project}/")
+    response: requests.Response = session.get(project_url, timeout=timeout)
     if response.status_code == 404:
         raise PyPINotFoundError
     response.raise_for_status()
@@ -228,7 +232,15 @@ def get_project_from_index(
     if not links:
         raise PyPINotFoundError
     for i in links:
-        url = i.attrib["href"]
+        parsed_dist_url = urlparse(i.attrib["href"])
+
+        # Per PEP 503: The distribution's URL can be relative, in which case
+        # it's relative to the project's simple index URL.
+        if not parsed_dist_url.netloc:
+            dist_url = urljoin(project_url, parsed_dist_url.geturl())
+        else:
+            dist_url = parsed_dist_url.geturl()
+
         py_req = i.attrib.get("data-requires-python")
         # Skip items that need a different Python version
         if py_req:
@@ -236,7 +248,7 @@ def get_project_from_index(
             if PYTHON_VERSION not in spec:
                 continue
 
-        path = urlparse(url).path
+        path = parsed_dist_url.path
         filename = path.rpartition("/")[-1]
 
         # Handle wheels and source distributions
@@ -256,7 +268,7 @@ def get_project_from_index(
                 name,
                 Path(filename),
                 version,
-                url=url,
+                url=dist_url,
                 extras=extras,
                 is_wheel=is_wheel,
                 timeout=timeout,
@@ -292,6 +304,10 @@ class PyPIProvider(AbstractProvider):
 
         `state` is an `AuditState` to use for state callbacks.
         """
+
+        # Per PEP 503: Index URLs should always be normalized to end with `/`.
+        index_urls = [url if url.endswith("/") else f"{url}/" for url in index_urls]
+
         self.index_urls = index_urls
         self.timeout = timeout
         self.session = caching_session(cache_dir, use_pip=True)
@@ -304,7 +320,7 @@ class PyPIProvider(AbstractProvider):
         return canonicalize_name(requirement_or_candidate.name)
 
     # TODO: Typing. See: https://github.com/sarugaku/resolvelib/issues/104
-    def get_preference(  # type: ignore[override, no-untyped-def]
+    def get_preference(  # type: ignore[no-untyped-def]
         self,
         identifier: Any,
         resolutions: Mapping[Any, Any],
